@@ -100,6 +100,7 @@ class DeepROC(FullROC):
         from deeproc.Helpers.DeepROCFunctions import concordant_partial_AUC
         from deeproc.Helpers.DeepROCFunctions import discrete_partial_roc_measures
         from deeproc.Helpers.DeepROCFunctions import partial_area_index_proxy
+        from deeproc.Helpers.DeepROCFunctions import standardized_partial_area_proxy
         from deeproc.Helpers.DeepROCFunctions import areEpsilonEqual
         from deeproc.Helpers.DeepROCFunctions import showConcordanceMatrixInfo
         from deeproc.Helpers.DeepROCFunctions import showCmeasures
@@ -251,9 +252,15 @@ class DeepROC(FullROC):
             showDiscretePartialAUCmeasures(groupIndex+1, measure_dict, showAllMeasures, verbose=verbose)
         #endif
 
+        sPA = standardized_partial_area_proxy(partial_fpr, partial_tpr, quiet)
+        measure_dict.update(dict(sPA=sPA))
+        if not quiet and verbose:
+            print(f"{'sPA':16s} = {sPA:0.4f}")
+        #endif
+
         # show PAI result only if the group ends at FPR == 0
         if self.groupAxis == 'FPR' and self.groups[groupIndex][0] == 1:
-            PAI = partial_area_index_proxy(partial_fpr, partial_fpr, quiet)
+            PAI = partial_area_index_proxy(partial_fpr, partial_tpr, quiet)
             measure_dict.update(dict(PAI=PAI))
             if not quiet and verbose:
                 print(f"{'PAI':16s} = {PAI:0.4f}  only applies to full or last range")
